@@ -1,11 +1,10 @@
 module.exports = {
-    "parser": "babel-eslint",
+    "parser": "@babel/eslint-parser",
     "plugins": [
         'flowtype',
         // 'react',
     ],
     'extends': [
-        // "google",
         'eslint:recommended',
         'plugin:flowtype/recommended',
         // 'plugin:react/recommended',
@@ -35,7 +34,11 @@ module.exports = {
         "indent": "off",
         "comma-dangle": "off",
         "no-console": "off",
+        "no-inner-declarations": "off",
+        "flowtype/space-before-type-colon": "off",
+        "no-unused-vars": ["error", {
+            "argsIgnorePattern": "^_",
+            "varsIgnorePattern": "^_"
+        }],
     }
-    // https://github.com/gajus/eslint-plugin-flowtype
-    // TODO use flow?
 };
