@@ -167,6 +167,20 @@ var Cls = {
     POPUP_LINK:'promnesia-visited-popup-link',
 }
 
+
+function _hasFormParent(element) {
+    var pel = element
+    while (pel != null) {
+        if (pel.tagName == "FORM") {
+            // todo maybe log?
+            return true
+        }
+        pel = pel.parentElement
+    }
+    return false
+}
+
+
 // TODO I guess, these snippets could be writable by people? and then they can customize tooltips to their liking
 /*
  * So, there are a few requirements from the marks we're trying to achieve here
@@ -191,6 +205,11 @@ function showMark(element) {
         return // no visits or was excluded (add some data attribute maybe?)
     }
 
+    if (_hasFormParent(element)) {
+        // workaround for this issue with github inline edits https://github.com/karlicoss/promnesia/issues/317
+        return
+    }
+
     // meh. might not work well on images etc...
     // todo would be nice though, e.g. on github in the 'contributors' view only avatars are displayed
     if (element.textContent.trim().length == 0) {
