@@ -1,19 +1,14 @@
 /* @flow */
-import {Visits, Visit, unwrap, format_duration, Methods, addStyle, Ids} from './common'
+import {Visits, Visit, unwrap, format_duration, Methods, addStyle, Ids, uuid, getOrDefault} from './common'
 import type {Second} from './common'
 import {getOptions, USE_ORIGINAL_TZ, GROUP_CONSECUTIVE_SECONDS} from './options';
 import type {Options} from './options';
 import {Binder, _fmt, asClass} from './display';
 import {defensify} from './notifications';
-import {achrome} from './async_chrome'
 
 // TODO how to prevent sidebar hiding on click??
 
-// TODO move to common?
-function get_or_default(obj, key, def) {
-    const res = obj[key];
-    return res === undefined ? def : res;
-}
+const UUID = uuid()
 
 const PROMNESIA_FRAME_ID   = 'promnesia-frame';
 const PROMNESIA_CLASS   = 'promnesia';
@@ -59,7 +54,7 @@ class Sidebar {
         return unwrap(frame.contentDocument.getElementById(CONTAINER_ID));
     }
 
-    setupFrame(frame) {
+    setupFrame(frame: HTMLIFrameElement): void {
         const cdoc = frame.contentDocument;
         const head = unwrap(cdoc.head);
 
@@ -71,6 +66,14 @@ class Sidebar {
         head.appendChild(link);
 
         addStyle(cdoc, this.opts.position_css);
+        // ugh. this is fucking horrible. hack to add default --right: 1 if it's not defined anywhere...
+        // I spent hours trying to implement it on pure css via vars/calc -- but didn't manage
+        {
+            const values = ['--right', '--left', '--top', '--bottom']
+            if (values.every(v => getComputedStyle(frame).getPropertyValue(v) == null)) {
+                frame.style.setProperty('--right', '1')
+            }
+        }
 
         // make links open in new tab instead of iframe https://stackoverflow.com/a/2656798/706389
         const base = cdoc.createElement('base');
@@ -82,6 +85,7 @@ class Sidebar {
         // it's a bit hacky.. but stuff inside and outside iframe got different namespace, so ok to reuse id?
         // makes it much easier for settings
         cbody.id = SIDEBAR_ID;
+        cbody.setAttribute('uuid', UUID)
 		const sidebar_header = cdoc.createElement('div');
         sidebar_header.id = HEADER_ID;
         const sidebar_toolbar = cdoc.createElement('div');
@@ -99,7 +103,7 @@ class Sidebar {
             // TODO hmm. not sure if defensify is gonna work from here? no access to notifications api?
             mark_visited_button.addEventListener('click', defensify(async () => {
                 mark_visited_button.classList.toggle('active');
-                await achrome.runtime.sendMessage({method: Methods.MARK_VISITED});
+                await browser.runtime.sendMessage({method: Methods.MARK_VISITED});
             }, 'mark_visited.onClick'));
             // TODO maybe highlight or just use custom class for that?
             mark_visited_button.title = "Mark visited links on the current";
@@ -111,7 +115,7 @@ class Sidebar {
             search_button.id = 'button-search';
             search_button.appendChild(cdoc.createTextNode('🔎 Search'));
             search_button.addEventListener('click', defensify(async () => {
-                await achrome.runtime.sendMessage({method: Methods.OPEN_SEARCH});
+                await browser.runtime.sendMessage({method: Methods.OPEN_SEARCH});
             }, 'open_search.onClick'));
 			search_button.title = "Search links in database";
             sidebar_toolbar.appendChild(search_button);
@@ -191,7 +195,6 @@ class Sidebar {
 
         const sidebar = doc.createElement('iframe'); this.body.appendChild(sidebar);
         sidebar.src = '';
-        sidebar.id = PROMNESIA_FRAME_ID;
 
 
         // TODO ugh it's a bit ridiculous that because of single iframe I have to propagate async everywhere..
@@ -199,6 +202,7 @@ class Sidebar {
             // TODO not sure if there is anything to reject?..
             sidebar.addEventListener('load', () => {resolve();}, {once: true});
         });
+        // todo add timeout to make it a bit easier to debug?
         await loadPromise;
 
         this.setupFrame(sidebar);
@@ -213,8 +217,9 @@ class Sidebar {
         // unless there is some sort of race condition?
         // requestVisits();
 
-
-        return sidebar;
+        // "publish" the frame, so other components can get it by that id
+        sidebar.id = PROMNESIA_FRAME_ID
+        return sidebar
     }
 
 }
@@ -286,6 +291,7 @@ function _highlight(text: string, idx: number, v: Visit) {
     for (let [line, target] of findMatches(unwrap(doc.body), lines)) {
         // https://developer.mozilla.org/en-US/docs/Web/API/Node/nodeType#Node_type_constants
         while (target != null && target.nodeType != Node.ELEMENT_NODE) {
+            // $FlowFixMe[incompatible-type]
             target = target.parentElement
         }
 
@@ -450,7 +456,8 @@ async function* _bindSidebarData(response: Visits) {
             tag = 'all';
             predicate = () => true;
         } else {
-            predicate = t => t == asClass(tag);
+            const tag_ = tag  // make Flow happy
+            predicate = t => t == asClass(tag_)
         }
 
         // TODO show total counts?
@@ -560,8 +567,8 @@ async function* _bindSidebarData(response: Visits) {
                 total_dur += v.duration;
             }
             for (const tag of v.tags) {
-                const mapped_tag = get_or_default(tag_map, tag, tag);
-                tset.add(mapped_tag);
+                const mapped_tag = getOrDefault(tag_map, tag, tag)
+                tset.add(mapped_tag)
             }
         }
         const tags = [...tset].sort();
@@ -592,11 +599,11 @@ async function bindSidebarData(response: Visits) {
 }
 
 
-
 // TODO ugh, it actually seems to erase all the class information :( is it due to message passing??
+// todo hmm this isn't used??
 // eslint-disable-next-line no-unused-vars
 function requestVisits(): void {
-    achrome.runtime.sendMessage({method: Methods.GET_SIDEBAR_VISITS})
+    browser.runtime.sendMessage({method: Methods.GET_SIDEBAR_VISITS})
            .then((response: {}) => {
                if (response == null) {
                    // todo why would it be?
@@ -607,8 +614,7 @@ function requestVisits(): void {
 }
 
 
-// eslint-disable-next-line no-unused-vars
-chrome.runtime.onMessage.addListener((msg: any, sender: chrome$MessageSender) => {
+const onMessageListener = (msg: any, _: chrome$MessageSender) => {
     const method = msg.method
     if        (method == Methods.BIND_SIDEBAR_VISITS) {
         bindSidebarData(Visits.fromJObject(msg.data))
@@ -618,7 +624,23 @@ chrome.runtime.onMessage.addListener((msg: any, sender: chrome$MessageSender) =>
         sidebar().then(s => s.toggle())
     }
     // todo do I need to return anything?
-})
+}
+
+
+const doc_body = unwrap(document.body)
+
+
+// this is necessary because due to data races it's possible for sidebar.js to be injected twice in the page
+// NOTE: we can't use window. variables here, seems that their state isn't preserved under geckodriver
+// see https://github.com/mozilla/geckodriver/issues/2075
+// perhaps have a separate version for testing purposes only??
+if (doc_body.getAttribute('promnesia_haslistener') == null) {
+    doc_body.setAttribute('promnesia_haslistener', 'true')
+    console.debug(`[promnesia] [sidebar-${UUID}] registering callbacks`)
+    chrome.runtime.onMessage.addListener(onMessageListener)
+} else {
+    console.debug(`[promnesia] [sidebar-${UUID}] skipping callback registration, they are already present`)
+}
 
 // TODO make configurable? or resizable?
 
