@@ -1,4 +1,4 @@
-from promnesia import Source
+from promnesia.common import Source
 from promnesia.sources import auto
 
 '''
@@ -12,6 +12,6 @@ SOURCES = [
         auto.index,
         # just some arbitrary directory with plaintext files
         '/usr/include/c++/',
-        '/usr/local/include/c++/', # on apple they are here apparenlty..
+        '/usr/local/include/c++/', # on apple they are here apparently..
     )
 ]
