@@ -3,11 +3,12 @@ A dummy source, used for testing
 Generates a sequence of fake evenly separated visits
 '''
 
-from ..common import Results, Visit, Loc
 from datetime import datetime, timedelta
 
+from ..common import Results, Visit, Loc
 
-def index(count=100, *, base_dt: datetime=datetime.min + timedelta(days=5000), delta=timedelta(hours=1)) -> Results:
+
+def index(count: int=100, *, base_dt: datetime=datetime.min + timedelta(days=5000), delta: timedelta=timedelta(hours=1)) -> Results:
     # todo with some errors too?
     # todo use data generation library suggested for HPI?
     for i in range(count):
