@@ -2,6 +2,7 @@ import os
 import sys
 from functools import wraps
 from pathlib import Path
+from typing import Iterator
 
 from promnesia.common import _is_windows
 
@@ -90,3 +91,10 @@ def reset_hpi_modules() -> None:
     to_unload = [m for m in sys.modules if re.match(r'my[.]?', m)]
     for m in to_unload:
         del sys.modules[m]
+
+
+@contextmanager
+def local_http_server(path: Path, *, port: int) -> Iterator[str]:
+    address = '127.0.0.1'
+    with tmp_popen([sys.executable, '-m', 'http.server', '--directory', path, '--bind', address, str(port)]) as popen:
+        yield f'http://{address}:{port}'
