@@ -4,20 +4,21 @@ import promnesia.sources as pkg
 import importlib
 
 
-def test_imports():
+# todo: circleci Windows got stuck with no response on these tests... not sure why, debug print didn't help
+def test_imports() -> None:
     '''
     Check that we at least have all necessary dependencies. Although it doesn't "really" guarantee anything?
     '''
     for importer, name, ispkg in pkgutil.walk_packages(
-            path=pkg.__path__,
+            path=pkg.__path__, # type: ignore
             prefix=pkg.__name__+'.'
     ):
         importlib.import_module(name)
 
 
-def test_imports_lazy():
+def test_imports_lazy() -> None:
     for importer, name, ispkg in pkgutil.walk_packages(
-            path=pkg.__path__,
+            path=pkg.__path__, # type: ignore
             prefix=pkg.__name__+'.'
     ):
         last = name.split('.')[-1]
